@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 9947 2017-05-04 10:37:30Z David $
+# $Id: __init__.py 9994 2017-05-28 14:47:33Z David $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: David $ (last)
-# $Date: 2017-05-04 18:37:30 +0800 (Thu, 04 May 2017) $
-# $Revision: 9947 $
+# $Date: 2017-05-28 22:47:33 +0800 (Sun, 28 May 2017) $
+# $Revision: 9994 $
 
 import os
 import sys
@@ -22,7 +22,6 @@ import warnings
 from Iuno import warnWithout, update, require
 from Iuppiter.DjangoUtil import (extendInstalledApps, extendMiddlewareClasses, 
                                  extendTemplateContextProcessors, 
-                                 extendSessionSerializer, 
                                  extendAuthenticationBackend)
 
 
@@ -94,11 +93,11 @@ def attachSettings(settingsDict, enableFacebook=False, enableGoogle=False,
     
     extendAuthenticationBackend(settingsDict, authenticationBackends)
     
-    sessionSerializers = (
+    defaultSessionSerializers = {
+        'SESSION_SERIALIZER': 
         'django.contrib.sessions.serializers.PickleSerializer'
-    )
-    
-    extendSessionSerializer(settingsDict, sessionSerializers)
+    }
+    update(settingsDict, defaultSessionSerializers)
     #=========================================================================
     
     #=========================================================================
